-- Titan [SimulationCraft]
-- Description: Titan plug-in to open Simulation Craft
-- Author: r1fT
-- Version: 1.0.2.70000

local _G = getfenv(0);
local TITAN_SIMULATIONCRAFT_ID = "SimulationCraft";
local TITAN_SIMULATIONCRAFT_VER = "1.0.0.70000";
local updateTable = {TITAN_SIMULATIONCRAFT_ID, TITAN_PANEL_UPDATE_BUTTON};
local buttonlabel = "Titan Panel [SimulationCraft]"
local L = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local AceTimer = LibStub("AceTimer-3.0")
local OverallAvg
local EquippedAvg

function GetItemLevel(iLink)
    name, link, quality, iLvl, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(iLink);
    if(iLvl == nil)then
        ilvl = 0;
    end
    return iLvl;
 end

function TitanPanelSimulationCraftButton_OnLoad(self)
	self.registry = {
		id = TITAN_SIMULATIONCRAFT_ID,
		version = TITAN_SIMULATIONCRAFT_VER,
		category = "Information",
		menuText = "Titan Panel [SimulationCraft]",
		buttonTextFunction = "TitanPanelSimulationCraftButton_GetButtonText", 
		tooltipTitle = "SimulationCraft",
		tooltipTextFunction = "TitanPanelSimulationCraftButton_GetTooltipText", 
		icon = "Interface\\Addons\\TitanSimulationCraft\\Icon",
		iconWidth = 16,
		controlVariables = {
			ShowIcon = true,
			ShowLabelText = true,
			DisplayOnRightSide = true
		},
		savedVariables = {
			ShowIcon = 1,
			DisplayOnRightSide = true
		}
	};
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

function TitanPanelSimulationCraftButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") and (not self:IsEventRegistered("PLAYER_EQUIPMENT_CHANGED")) then
		self:RegisterEvent("PLAYER_EQUIPMENT_CHANGED");
	end

	if event == "PLAYER_EQUIPMENT_CHANGED" then
		self:SetScript("OnUpdate", TitanPanelSimulationCraftButton_OnUpdate)
	end
end

function TitanPanelSimulationCraftButton_OnUpdate(self)
	TitanPanelPluginHandle_OnUpdate(updateTable)
	self:SetScript("OnUpdate", nil)
end

function TitanPanelSimulationCraftButton_OnClick(self, button)
	if (button == "LeftButton") then
		local editbox=ChatEdit_ChooseBoxForSend(DEFAULT_CHAT_FRAME);
		ChatEdit_ActivateChat(editbox);
		editbox:SetText("/simc");
		ChatEdit_OnEnterPressed(editbox);
	end
end

function TitanPanelSimulationCraftButton_GetButtonText(id)
	return buttonlabel, "|r"
end

function TitanPanelSimulationCraftButton_GetTooltipText()
	SimCItems = "\n";
	if GetInventoryItemLink("player", INVSLOT_HEAD) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_HEAD);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Helm: 	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Helm: 	|cFFFFFFFFNone|r \n";
	end
	if GetInventoryItemLink("player", INVSLOT_NECK) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_NECK);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Neck:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Neck: 	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_SHOULDER) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_SHOULDER);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Shoulder: 	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Shoulder: 	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_BACK) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_BACK);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Back:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Back:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_CHEST) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_CHEST);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Chest:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Chest:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_WAIST) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_WAIST);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Waist:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Waist:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_LEGS) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_LEGS);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Legs:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Legs:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_FEET) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_FEET);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Feet:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Feet:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_WRIST) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_WRIST);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Wrist:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Wrist:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_HAND) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_HAND);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Hands:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Hands:	|cFFFFFFFFNone\n";
		end
	if GetInventoryItemLink("player", INVSLOT_FINGER1) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_FINGER1);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Ring:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Ring:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_FINGER2) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_FINGER2);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Ring:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Ring:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_TRINKET1) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_TRINKET1);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Trinket:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Trinket:	|cFFFFFFFFNone\n";
	end
	if GetInventoryItemLink("player", INVSLOT_TRINKET2) ~= nil then
		iLink = GetInventoryItemLink("player", INVSLOT_TRINKET2);
		iLvl = GetItemLevel(iLink);
		SimCItems = SimCItems.."Trinket:	"..iLink.." - |cFFFFFFFF"..iLvl.."|r \n";
	else
		SimCItems = SimCItems.."Trinket:	|cFFFFFFFFNone\n";
	end
	EquippedAvg = string.format("%d",select(2,GetAverageItemLevel("player")));
	SimCItems = SimCItems.."\nAverage Item Level: |cFF0055FF"..EquippedAvg.."|r \n";
	SimCItems = SimCItems.."|cff00ff00Left-click for SimulationCraft export.|r";
	return SimCItems
end

function TitanPanelRightClickMenu_PrepareSimulationCraftMenu()
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_SIMULATIONCRAFT_ID].menuText);
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(L["TITAN_PANEL_MENU_HIDE"], TITAN_SIMULATIONCRAFT_ID, TITAN_PANEL_MENU_FUNC_HIDE);
end


